@@ -5,7 +5,10 @@ from src.utilities.running_os import *
 from src.input.anim_input import *
 from src.input.ask_input import *
 from src.console.clear_console import *
-
+def test_smi():
+    for i in range(100):
+        print(i)
+    clear_console("line")
 def ask_input(text,type="str"):
     while True:
         if type == "str":
